<a name="readme-top"></a>

<div align="center">
  <h1 align="center">Mixy</h1>

  <p align="center">
    A customizable project templater!
    <br />
    <a href="https://github.com/alexisbeaulieu97/Mixy/issues">Report Bug</a>
    ·
    <a href="https://github.com/alexisbeaulieu97/Mixy/issues">Request Feature</a>
  </p>
</div>

# About the project

Mixy is a CLI tool used to create projects based on one or multiple templates.

> **Warning** This project is in early development and is rapidly evolving.
> This means you can expect:
> * Missing features
> * No stability guarantees
> * Bugs

# Getting Started

## Prerequisites

This project requires python 3.11 or later to be installed.

## Installation

Installation can be done using pip.
```shell
pip install mixy
```

<p align="right"><a href="#readme-top">back to top</a></p>

## Usage

<p align="right"><a href="#readme-top">back to top</a></p>

# License

See the [LICENSE](LICENSE) file.

<p align="right"><a href="#readme-top">back to top</a></p>

# Authors

* [Alexis Beaulieu](https://www.linkedin.com/in/alexisbeaulieu/)

<p align="right"><a href="#readme-top">back to top</a></p>
